@@ -1,3 +1,3 @@
-@app.get("/items/{item_id}")
+@api.get("/items/{item_id}")
 def read_item(request, item_id):
     return {"item_id": item_id}
