@@ -1,4 +1,7 @@
+from typing import Callable
+
 import django
+from django.http import HttpRequest
 
 try:
     from django.utils.datastructures import CaseInsensitiveMapping
@@ -6,7 +9,7 @@ except ImportError:
     from .datastructures import CaseInsensitiveMapping
 
 
-# HttpHeaders copypated from django 3.0 codebase
+# HttpHeaders copypasted from django 3.0 codebase
 class HttpHeaders(CaseInsensitiveMapping):
     HTTP_PREFIX = "HTTP_"
     # PEP 333 gives two headers which aren't prepended with HTTP_.
@@ -27,7 +30,8 @@ class HttpHeaders(CaseInsensitiveMapping):
     @classmethod
     def parse_header_name(cls, header):
         if header.startswith(cls.HTTP_PREFIX):
-            header = header[len(cls.HTTP_PREFIX) :]
+            start = len(cls.HTTP_PREFIX)
+            header = header[start:]
         elif header not in cls.UNPREFIXED_HEADERS:
             return None
         return header.replace("_", "-").title()
@@ -41,6 +45,8 @@ def get_headers_v3(request):
     return request.headers
 
 
+get_headers: Callable[[HttpRequest], HttpHeaders]
+
 if django.VERSION[0] < 3:
     get_headers = get_headers_old
 else:
