@@ -1,10 +1,18 @@
 from functools import partial
+from typing import TYPE_CHECKING, Any, List
+
 from django.urls import path
-from .views import openapi_json, swagger, home
+
+from .views import default_home, openapi_json, swagger
+
+if TYPE_CHECKING:
+    from ninja import NinjaAPI  # pragma: no cover
+
+__all__ = ["get_openapi_urls", "get_root_url"]
 
 
-def get_openapi_urls(api: "NinjaAPI"):
-    result = [path("", partial(home, api=api), name=f"api-root")]
+def get_openapi_urls(api: "NinjaAPI") -> List[Any]:
+    result = []
 
     if api.openapi_url:
         result.append(
@@ -29,3 +37,7 @@ def get_openapi_urls(api: "NinjaAPI"):
             )
 
     return result
+
+
+def get_root_url(api: "NinjaAPI") -> Any:
+    return path("", partial(default_home, api=api), name="api-root")
