@@ -1,4 +1,4 @@
-from ninja import NinjaAPI
+from ninja import NinjaAPI, Router
 from ninja.security import APIKeyQuery
 from client import NinjaClient
 
@@ -33,6 +33,25 @@ def multi_auth(request):
     return {"auth": request.auth}
 
 
+# ---- router ------------------------
+
+router = Router()
+
+
+@router.get("/router-operation")  # should come from global auth
+def router_operation(request):
+    return {"auth": str(request.auth)}
+
+
+@router.get("/router-operation-auth", auth=KeyQuery2())
+def router_operation_auth(request):
+    return {"auth": str(request.auth)}
+
+
+api.add_router("", router)
+
+# ---- end router --------------------
+
 client = NinjaClient(api)
 
 
@@ -51,3 +70,11 @@ def test_multi():
 
     assert client.post("/multi-method-auth?key=k2").json() == {"auth": "k2"}
     assert client.patch("/multi-method-auth?key=k2").json() == {"auth": "k2"}
+
+
+def test_router_auth():
+    assert client.get("/router-operation").status_code == 401
+    assert client.get("/router-operation?key=k1").json() == {"auth": "k1"}
+
+    assert client.get("/router-operation-auth?key=k1").status_code == 401
+    assert client.get("/router-operation-auth?key=k2").json() == {"auth": "k2"}
